@@ -75,7 +75,15 @@ def show_header():
     try:
         latest_one = Post.objects.filter(status=1).latest('updated_on')
     except Post.DoesNotExist:
-        latest_one = None
+        from django.contrib.auth.models import User
+        u = User.objects.all()[0]
+        p = Post(title="test",
+                 slug="test",
+                 author=u,
+                 content="test",
+                 status=1)
+        p.save()
+        latest_one = p
     return {
         'category': CATEGORY,
         'latest_one': latest_one,
